// Copyright 2023 Specter Ops, Inc.
//
// Licensed under the Apache License, Version 2.0
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// SPDX-License-Identifier: Apache-2.0

package datapipe_test

import (
	"testing"
	"time"

	"github.com/specterops/bloodhound/cmd/api/src/daemons/datapipe"
	"github.com/stretchr/testify/require"
)

func TestRandomDurationBetween(t *testing.T) {
	const (
		min = time.Minute
		max = 10 * time.Minute
	)

	for i := 0; i < 1000; i++ {
		randomDuration := datapipe.RandomDurationBetween(min, max)

		require.True(t, min < randomDuration)
		require.True(t, max > randomDuration)
	}
}
